==> konclude_0.6.1.orig.tar.gz: Konclude-v0.6.1-527-SourceCode/Source/Reasoner/Consistiser/CIndividualDependenceTrackingCollector.cpp <==
/*
 *		Copyright (C) 2013, 2014, 2015 by the Konclude Developer Team.
 *
 *		This file is part of the reasoning system Konclude.
 *		For details and support, see <http://konclude.com/>.
 *
 *		Konclude is free software: you can redistribute it and/or modify it under
 *		the terms of version 2.1 of the GNU Lesser General Public License (LGPL2.1)
 *		as published by the Free Software Foundation.
 *
 *		You should have received a copy of the GNU Lesser General Public License
 *		along with Konclude. If not, see <http://www.gnu.org/licenses/>.
 *
 *		Konclude is distributed in the hope that it will be useful,
 *		but WITHOUT ANY WARRANTY; without even the implied warranty of
 *		MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. For more
 *		details, see GNU Lesser General Public License.
 *
 */

#include "CIndividualDependenceTrackingCollector.h"


namespace Konclude {

	namespace Reasoner {

		namespace Consistiser {


			CIndividualDependenceTrackingCollector::CIndividualDependenceTrackingCollector() {
			}


			CIndividualDependenceTrackingCollector::~CIndividualDependenceTrackingCollector() {
			}


			CIndividualDependenceTracking* CIndividualDependenceTrackingCollector::getExtendingIndividualDependenceTracking() {
				return mIndiDepTrackingPointer;
			}

			CIndividualDependenceTracking* CIndividualDependenceTrackingCollector::installIndividualDependenceTracking(CIndividualDependenceTracking* indDepTrack) {
				if (!mIndiDepTrackingPointer.testAndSetOrdered(nullptr,indDepTrack)) {
					delete indDepTrack;
				}
				return mIndiDepTrackingPointer;
			}



		}; // end namespace Consistiser

	}; // end namespace Reasoner

}; // end namespace Konclude

==> konclude_0.6.2~dfsg.orig.tar.gz: Konclude-v0.6.2-544-SourceCode/Source/Reasoner/Consistiser/CIndividualDependenceTrackingCollector.cpp <==
/*
 *		Copyright (C) 2013, 2014, 2015 by the Konclude Developer Team.
 *
 *		This file is part of the reasoning system Konclude.
 *		For details and support, see <http://konclude.com/>.
 *
 *		Konclude is free software: you can redistribute it and/or modify it under
 *		the terms of version 2.1 of the GNU Lesser General Public License (LGPL2.1)
 *		as published by the Free Software Foundation.
 *
 *		You should have received a copy of the GNU Lesser General Public License
 *		along with Konclude. If not, see <http://www.gnu.org/licenses/>.
 *
 *		Konclude is distributed in the hope that it will be useful,
 *		but WITHOUT ANY WARRANTY; without even the implied warranty of
 *		MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. For more
 *		details, see GNU Lesser General Public License.
 *
 */

#include "CIndividualDependenceTrackingCollector.h"


namespace Konclude {

	namespace Reasoner {

		namespace Consistiser {


			CIndividualDependenceTrackingCollector::CIndividualDependenceTrackingCollector() {
			}


			CIndividualDependenceTrackingCollector::~CIndividualDependenceTrackingCollector() {
			}


			CIndividualDependenceTracking* CIndividualDependenceTrackingCollector::getExtendingIndividualDependenceTracking() {
                return mIndiDepTrackingPointer.fetchAndAddRelaxed(0);
			}

			CIndividualDependenceTracking* CIndividualDependenceTrackingCollector::installIndividualDependenceTracking(CIndividualDependenceTracking* indDepTrack) {
				if (!mIndiDepTrackingPointer.testAndSetOrdered(nullptr,indDepTrack)) {
					delete indDepTrack;
				}
                return mIndiDepTrackingPointer.fetchAndAddRelaxed(0);
			}



		}; // end namespace Consistiser

	}; // end namespace Reasoner

}; // end namespace Konclude
